@@ -1,10 +1,10 @@
 #' Keyboard and Mouse Input Simulation for Windows OS
-#' 
+#'
 #' Control your keyboard and mouse with R code by simulating key presses and mouse clicks. The input simulation is implemented with the Windows API.
-#' 
+#'
+"_PACKAGE"
 #' @docType package
 #' @author Jim Chen, Jeff Keller
 #' @import Rcpp
 #' @useDynLib KeyboardSimulator
 #' @name KeyboardSimulator
-NULL
